==> jc-1.4.0.tar.gz: gnu/regexp/RESyntax.h <==
// public final class gnu.regexp.RESyntax

// class file dependencies
// @dep_class f36b91076fd92dcd gnu_regexp_RESyntax
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_regexp_RESyntax_H_
#define _JC_gnu_regexp_RESyntax_H_

// Forward structure declarations
struct _jc_gnu_regexp_RESyntax$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_BitSet$object;

// Typedefs
typedef struct _jc_gnu_regexp_RESyntax$sub_refs	_jc_gnu_regexp_RESyntax$sub_refs;
typedef struct _jc_gnu_regexp_RESyntax$sub_nonrefs	_jc_gnu_regexp_RESyntax$sub_nonrefs;
typedef struct _jc_gnu_regexp_RESyntax$refs	_jc_gnu_regexp_RESyntax$refs;
typedef struct _jc_gnu_regexp_RESyntax$nonrefs	_jc_gnu_regexp_RESyntax$nonrefs;
typedef struct _jc_gnu_regexp_RESyntax$object	_jc_gnu_regexp_RESyntax$object;

typedef struct _jc_gnu_regexp_RESyntax$fields_struct	_jc_gnu_regexp_RESyntax$fields_struct;
typedef const struct _jc_gnu_regexp_RESyntax$vmethods	_jc_gnu_regexp_RESyntax$vmethods;
typedef const struct _jc_gnu_regexp_RESyntax$vtable	_jc_gnu_regexp_RESyntax$vtable;
typedef const struct _jc_gnu_regexp_RESyntax$vtype	_jc_gnu_regexp_RESyntax$vtype;

// Class fields structure
struct _jc_gnu_regexp_RESyntax$fields_struct {
	struct _jc_java_lang_String$object	*DEFAULT__5fLINE__5fSEPARATOR;
	struct _jc_gnu_regexp_RESyntax$object	*RE__5fSYNTAX__5fAWK;
	struct _jc_gnu_regexp_RESyntax$object	*RE__5fSYNTAX__5fED;
	struct _jc_gnu_regexp_RESyntax$object	*RE__5fSYNTAX__5fEGREP;
	struct _jc_gnu_regexp_RESyntax$object	*RE__5fSYNTAX__5fEMACS;
	struct _jc_gnu_regexp_RESyntax$object	*RE__5fSYNTAX__5fGREP;
	struct _jc_gnu_regexp_RESyntax$object	*RE__5fSYNTAX__5fJAVA__5f1__5f4;
	struct _jc_gnu_regexp_RESyntax$object	*RE__5fSYNTAX__5fPERL4;
	struct _jc_gnu_regexp_RESyntax$object	*RE__5fSYNTAX__5fPERL4__5fS;
	struct _jc_gnu_regexp_RESyntax$object	*RE__5fSYNTAX__5fPERL5;
	struct _jc_gnu_regexp_RESyntax$object	*RE__5fSYNTAX__5fPERL5__5fS;
	struct _jc_gnu_regexp_RESyntax$object	*RE__5fSYNTAX__5fPOSIX__5fAWK;
	struct _jc_gnu_regexp_RESyntax$object	*RE__5fSYNTAX__5fPOSIX__5fBASIC;
	struct _jc_gnu_regexp_RESyntax$object	*RE__5fSYNTAX__5fPOSIX__5fEGREP;
	struct _jc_gnu_regexp_RESyntax$object	*RE__5fSYNTAX__5fPOSIX__5fEXTENDED;
	struct _jc_gnu_regexp_RESyntax$object	*RE__5fSYNTAX__5fPOSIX__5fMINIMAL__5fBASIC;
	struct _jc_gnu_regexp_RESyntax$object	*RE__5fSYNTAX__5fPOSIX__5fMINIMAL__5fEXTENDED;
	struct _jc_gnu_regexp_RESyntax$object	*RE__5fSYNTAX__5fSED;
	struct _jc_java_lang_String$object	*SYNTAX__5fIS__5fFINAL;
	jint	BIT__5fTOTAL;
	jint	RE__5fBACKSLASH__5fESCAPE__5fIN__5fLISTS;
	jint	RE__5fBK__5fPLUS__5fQM;
	jint	RE__5fCHAR__5fCLASSES;
	jint	RE__5fCHAR__5fCLASS__5fESCAPES;
	jint	RE__5fCHAR__5fCLASS__5fESC__5fIN__5fLISTS;
	jint	RE__5fCOMMENTS;
	jint	RE__5fCONTEXT__5fINDEP__5fANCHORS;
	jint	RE__5fCONTEXT__5fINDEP__5fOPS;
	jint	RE__5fCONTEXT__5fINVALID__5fOPS;
	jint	RE__5fDOT__5fNEWLINE;
	jint	RE__5fDOT__5fNOT__5fNULL;
	jint	RE__5fHAT__5fLISTS__5fNOT__5fNEWLINE;
	jint	RE__5fINTERVALS;
	jint	RE__5fLIMITED__5fOPS;
	jint	RE__5fLOOKAHEAD;
	jint	RE__5fNEWLINE__5fALT;
	jint	RE__5fNO__5fBK__5fBRACES;
	jint	RE__5fNO__5fBK__5fPARENS;
	jint	RE__5fNO__5fBK__5fREFS;
	jint	RE__5fNO__5fBK__5fVBAR;
	jint	RE__5fNO__5fEMPTY__5fRANGES;
	jint	RE__5fPURE__5fGROUPING;
	jint	RE__5fSTINGY__5fOPS;
	jint	RE__5fSTRING__5fANCHORS;
	jint	RE__5fUNMATCHED__5fRIGHT__5fPAREN__5fORD;
};
extern _jc_gnu_regexp_RESyntax$fields_struct _jc_gnu_regexp_RESyntax$class_fields;

// Constructors
extern void _jc_gnu_regexp_RESyntax$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_regexp_RESyntax$object *);
extern void _jc_gnu_regexp_RESyntax$method$_init$87edbea769b6ef1f(_jc_env *, struct _jc_gnu_regexp_RESyntax$object *, struct _jc_gnu_regexp_RESyntax$object *);

// Virtual methods
extern struct _jc_gnu_regexp_RESyntax$object *_jc_gnu_regexp_RESyntax$method$clear$1a1e6de73b4a4156(_jc_env *, struct _jc_gnu_regexp_RESyntax$object *, jint);
extern jboolean _jc_gnu_regexp_RESyntax$method$get$38ccc678c0c2c3ad(_jc_env *, struct _jc_gnu_regexp_RESyntax$object *, jint);
extern struct _jc_java_lang_String$object *_jc_gnu_regexp_RESyntax$method$getLineSeparator$49650f9c32e2e981(_jc_env *, struct _jc_gnu_regexp_RESyntax$object *);
extern struct _jc_gnu_regexp_RESyntax$object *_jc_gnu_regexp_RESyntax$method$makeFinal$4fbf6f93fdf1f302(_jc_env *, struct _jc_gnu_regexp_RESyntax$object *);
extern struct _jc_gnu_regexp_RESyntax$object *_jc_gnu_regexp_RESyntax$method$set$f255d8608394141a(_jc_env *, struct _jc_gnu_regexp_RESyntax$object *, jint);
extern struct _jc_gnu_regexp_RESyntax$object *_jc_gnu_regexp_RESyntax$method$setLineSeparator$c07dad0dfe692f53(_jc_env *, struct _jc_gnu_regexp_RESyntax$object *, struct _jc_java_lang_String$object *);
extern void _jc_gnu_regexp_RESyntax$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_regexp_RESyntax$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_regexp_RESyntax$method_info$clear$1a1e6de73b4a4156;
extern _jc_method _jc_gnu_regexp_RESyntax$method_info$get$38ccc678c0c2c3ad;
extern _jc_method _jc_gnu_regexp_RESyntax$method_info$getLineSeparator$49650f9c32e2e981;
extern _jc_method _jc_gnu_regexp_RESyntax$method_info$makeFinal$4fbf6f93fdf1f302;
extern _jc_method _jc_gnu_regexp_RESyntax$method_info$set$f255d8608394141a;
extern _jc_method _jc_gnu_regexp_RESyntax$method_info$setLineSeparator$c07dad0dfe692f53;
extern _jc_method _jc_gnu_regexp_RESyntax$method_info$this$adc93fb6bf4cbffa;

// Static methods
extern void _jc_gnu_regexp_RESyntax$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_gnu_regexp_RESyntax$vmethods {
	struct _jc_gnu_regexp_RESyntax$object	*(*clear$1a1e6de73b4a4156)(_jc_env *, struct _jc_gnu_regexp_RESyntax$object *, jint);
	jboolean	(*get$38ccc678c0c2c3ad)(_jc_env *, struct _jc_gnu_regexp_RESyntax$object *, jint);
	struct _jc_java_lang_String$object	*(*getLineSeparator$49650f9c32e2e981)(_jc_env *, struct _jc_gnu_regexp_RESyntax$object *);
	struct _jc_gnu_regexp_RESyntax$object	*(*makeFinal$4fbf6f93fdf1f302)(_jc_env *, struct _jc_gnu_regexp_RESyntax$object *);
	struct _jc_gnu_regexp_RESyntax$object	*(*set$f255d8608394141a)(_jc_env *, struct _jc_gnu_regexp_RESyntax$object *, jint);
	struct _jc_gnu_regexp_RESyntax$object	*(*setLineSeparator$c07dad0dfe692f53)(_jc_env *, struct _jc_gnu_regexp_RESyntax$object *, struct _jc_java_lang_String$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_regexp_RESyntax$object *);
};

// Vtable
struct _jc_gnu_regexp_RESyntax$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_regexp_RESyntax$vmethods	gnu_regexp_RESyntax;
};

// Vtype
struct _jc_gnu_regexp_RESyntax$vtype {
	_jc_type			type;
	_jc_gnu_regexp_RESyntax$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_regexp_RESyntax$sub_refs {
	struct _jc_java_util_BitSet$object	*bits;
	struct _jc_java_lang_String$object	*lineSeparator;
};

// Reference instance fields (object)
struct _jc_gnu_regexp_RESyntax$refs {
    _jc_gnu_regexp_RESyntax$sub_refs	gnu_regexp_RESyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_regexp_RESyntax$sub_nonrefs {
	jboolean	isFinal;
};

// Non-reference instance fields (object)
struct _jc_gnu_regexp_RESyntax$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_regexp_RESyntax$sub_nonrefs	gnu_regexp_RESyntax;
};

// Object instance structure
struct _jc_gnu_regexp_RESyntax$object {
	_jc_gnu_regexp_RESyntax$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_regexp_RESyntax$vtype	*vtype;
	_jc_gnu_regexp_RESyntax$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_regexp_RESyntax$vtype _jc_gnu_regexp_RESyntax$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_regexp_RESyntax, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_regexp_RESyntax$class_object;

#endif	/* _JC_gnu_regexp_RESyntax_H_ */

==> jc-1.4.5.tar.gz: gnu/regexp/RESyntax.h <==
// public final class gnu.regexp.RESyntax

// class file dependencies
// @dep_class f36b91076fd92dcd gnu_regexp_RESyntax
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_regexp_RESyntax_H_
#define _JC_gnu_regexp_RESyntax_H_

// Forward structure declarations
struct _jc_gnu_regexp_RESyntax$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_BitSet$object;

// Typedefs
typedef struct _jc_gnu_regexp_RESyntax$sub_refs	_jc_gnu_regexp_RESyntax$sub_refs;
typedef struct _jc_gnu_regexp_RESyntax$sub_nonrefs	_jc_gnu_regexp_RESyntax$sub_nonrefs;
typedef struct _jc_gnu_regexp_RESyntax$refs	_jc_gnu_regexp_RESyntax$refs;
typedef struct _jc_gnu_regexp_RESyntax$nonrefs	_jc_gnu_regexp_RESyntax$nonrefs;
typedef struct _jc_gnu_regexp_RESyntax$object	_jc_gnu_regexp_RESyntax$object;

typedef struct _jc_gnu_regexp_RESyntax$fields_struct	_jc_gnu_regexp_RESyntax$fields_struct;
typedef const struct _jc_gnu_regexp_RESyntax$vmethods	_jc_gnu_regexp_RESyntax$vmethods;
typedef const struct _jc_gnu_regexp_RESyntax$vtable	_jc_gnu_regexp_RESyntax$vtable;
typedef const struct _jc_gnu_regexp_RESyntax$vtype	_jc_gnu_regexp_RESyntax$vtype;

// Class fields structure
struct _jc_gnu_regexp_RESyntax$fields_struct {
	struct _jc_java_lang_String$object	*DEFAULT__5fLINE__5fSEPARATOR;
	struct _jc_gnu_regexp_RESyntax$object	*RE__5fSYNTAX__5fAWK;
	struct _jc_gnu_regexp_RESyntax$object	*RE__5fSYNTAX__5fED;
	struct _jc_gnu_regexp_RESyntax$object	*RE__5fSYNTAX__5fEGREP;
	struct _jc_gnu_regexp_RESyntax$object	*RE__5fSYNTAX__5fEMACS;
	struct _jc_gnu_regexp_RESyntax$object	*RE__5fSYNTAX__5fGREP;
	struct _jc_gnu_regexp_RESyntax$object	*RE__5fSYNTAX__5fJAVA__5f1__5f4;
	struct _jc_gnu_regexp_RESyntax$object	*RE__5fSYNTAX__5fPERL4;
	struct _jc_gnu_regexp_RESyntax$object	*RE__5fSYNTAX__5fPERL4__5fS;
	struct _jc_gnu_regexp_RESyntax$object	*RE__5fSYNTAX__5fPERL5;
	struct _jc_gnu_regexp_RESyntax$object	*RE__5fSYNTAX__5fPERL5__5fS;
	struct _jc_gnu_regexp_RESyntax$object	*RE__5fSYNTAX__5fPOSIX__5fAWK;
	struct _jc_gnu_regexp_RESyntax$object	*RE__5fSYNTAX__5fPOSIX__5fBASIC;
	struct _jc_gnu_regexp_RESyntax$object	*RE__5fSYNTAX__5fPOSIX__5fEGREP;
	struct _jc_gnu_regexp_RESyntax$object	*RE__5fSYNTAX__5fPOSIX__5fEXTENDED;
	struct _jc_gnu_regexp_RESyntax$object	*RE__5fSYNTAX__5fPOSIX__5fMINIMAL__5fBASIC;
	struct _jc_gnu_regexp_RESyntax$object	*RE__5fSYNTAX__5fPOSIX__5fMINIMAL__5fEXTENDED;
	struct _jc_gnu_regexp_RESyntax$object	*RE__5fSYNTAX__5fSED;
	struct _jc_java_lang_String$object	*SYNTAX__5fIS__5fFINAL;
	jint	BIT__5fTOTAL;
	jint	RE__5fBACKSLASH__5fESCAPE__5fIN__5fLISTS;
	jint	RE__5fBK__5fPLUS__5fQM;
	jint	RE__5fCHAR__5fCLASSES;
	jint	RE__5fCHAR__5fCLASS__5fESCAPES;
	jint	RE__5fCHAR__5fCLASS__5fESC__5fIN__5fLISTS;
	jint	RE__5fCOMMENTS;
	jint	RE__5fCONTEXT__5fINDEP__5fANCHORS;
	jint	RE__5fCONTEXT__5fINDEP__5fOPS;
	jint	RE__5fCONTEXT__5fINVALID__5fOPS;
	jint	RE__5fDOT__5fNEWLINE;
	jint	RE__5fDOT__5fNOT__5fNULL;
	jint	RE__5fHAT__5fLISTS__5fNOT__5fNEWLINE;
	jint	RE__5fINTERVALS;
	jint	RE__5fLIMITED__5fOPS;
	jint	RE__5fLOOKAHEAD;
	jint	RE__5fNEWLINE__5fALT;
	jint	RE__5fNO__5fBK__5fBRACES;
	jint	RE__5fNO__5fBK__5fPARENS;
	jint	RE__5fNO__5fBK__5fREFS;
	jint	RE__5fNO__5fBK__5fVBAR;
	jint	RE__5fNO__5fEMPTY__5fRANGES;
	jint	RE__5fPURE__5fGROUPING;
	jint	RE__5fSTINGY__5fOPS;
	jint	RE__5fSTRING__5fANCHORS;
	jint	RE__5fUNMATCHED__5fRIGHT__5fPAREN__5fORD;
};
extern _jc_gnu_regexp_RESyntax$fields_struct _jc_gnu_regexp_RESyntax$class_fields;

// Constructors
extern void _jc_gnu_regexp_RESyntax$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_regexp_RESyntax$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_regexp_RESyntax$method$_init$87edbea769b6ef1f(_jc_env *, struct _jc_gnu_regexp_RESyntax$object *, struct _jc_gnu_regexp_RESyntax$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_gnu_regexp_RESyntax$object *_jc_gnu_regexp_RESyntax$method$clear$1a1e6de73b4a4156(_jc_env *, struct _jc_gnu_regexp_RESyntax$object *, jint) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_regexp_RESyntax$method$get$38ccc678c0c2c3ad(_jc_env *, struct _jc_gnu_regexp_RESyntax$object *, jint) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_regexp_RESyntax$method$getLineSeparator$49650f9c32e2e981(_jc_env *, struct _jc_gnu_regexp_RESyntax$object *) _JC_JCNI_ATTR;
extern struct _jc_gnu_regexp_RESyntax$object *_jc_gnu_regexp_RESyntax$method$makeFinal$4fbf6f93fdf1f302(_jc_env *, struct _jc_gnu_regexp_RESyntax$object *) _JC_JCNI_ATTR;
extern struct _jc_gnu_regexp_RESyntax$object *_jc_gnu_regexp_RESyntax$method$set$f255d8608394141a(_jc_env *, struct _jc_gnu_regexp_RESyntax$object *, jint) _JC_JCNI_ATTR;
extern struct _jc_gnu_regexp_RESyntax$object *_jc_gnu_regexp_RESyntax$method$setLineSeparator$c07dad0dfe692f53(_jc_env *, struct _jc_gnu_regexp_RESyntax$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_regexp_RESyntax$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_regexp_RESyntax$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_regexp_RESyntax$method_info$clear$1a1e6de73b4a4156;
extern _jc_method _jc_gnu_regexp_RESyntax$method_info$get$38ccc678c0c2c3ad;
extern _jc_method _jc_gnu_regexp_RESyntax$method_info$getLineSeparator$49650f9c32e2e981;
extern _jc_method _jc_gnu_regexp_RESyntax$method_info$makeFinal$4fbf6f93fdf1f302;
extern _jc_method _jc_gnu_regexp_RESyntax$method_info$set$f255d8608394141a;
extern _jc_method _jc_gnu_regexp_RESyntax$method_info$setLineSeparator$c07dad0dfe692f53;
extern _jc_method _jc_gnu_regexp_RESyntax$method_info$this$adc93fb6bf4cbffa;

// Static methods
extern void _jc_gnu_regexp_RESyntax$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_regexp_RESyntax$vmethods {
	struct _jc_gnu_regexp_RESyntax$object	*(*clear$1a1e6de73b4a4156)(_jc_env *, struct _jc_gnu_regexp_RESyntax$object *, jint) _JC_JCNI_ATTR;
	jboolean	(*get$38ccc678c0c2c3ad)(_jc_env *, struct _jc_gnu_regexp_RESyntax$object *, jint) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getLineSeparator$49650f9c32e2e981)(_jc_env *, struct _jc_gnu_regexp_RESyntax$object *) _JC_JCNI_ATTR;
	struct _jc_gnu_regexp_RESyntax$object	*(*makeFinal$4fbf6f93fdf1f302)(_jc_env *, struct _jc_gnu_regexp_RESyntax$object *) _JC_JCNI_ATTR;
	struct _jc_gnu_regexp_RESyntax$object	*(*set$f255d8608394141a)(_jc_env *, struct _jc_gnu_regexp_RESyntax$object *, jint) _JC_JCNI_ATTR;
	struct _jc_gnu_regexp_RESyntax$object	*(*setLineSeparator$c07dad0dfe692f53)(_jc_env *, struct _jc_gnu_regexp_RESyntax$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_regexp_RESyntax$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_regexp_RESyntax$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_regexp_RESyntax$vmethods	gnu_regexp_RESyntax;
};

// Vtype
struct _jc_gnu_regexp_RESyntax$vtype {
	_jc_type			type;
	_jc_gnu_regexp_RESyntax$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_regexp_RESyntax$sub_refs {
	struct _jc_java_util_BitSet$object	*bits;
	struct _jc_java_lang_String$object	*lineSeparator;
};

// Reference instance fields (object)
struct _jc_gnu_regexp_RESyntax$refs {
    _jc_gnu_regexp_RESyntax$sub_refs	gnu_regexp_RESyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_regexp_RESyntax$sub_nonrefs {
	jboolean	isFinal;
};

// Non-reference instance fields (object)
struct _jc_gnu_regexp_RESyntax$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_regexp_RESyntax$sub_nonrefs	gnu_regexp_RESyntax;
};

// Object instance structure
struct _jc_gnu_regexp_RESyntax$object {
	_jc_gnu_regexp_RESyntax$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_regexp_RESyntax$vtype	*vtype;
	_jc_gnu_regexp_RESyntax$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_regexp_RESyntax$vtype _jc_gnu_regexp_RESyntax$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_regexp_RESyntax, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_regexp_RESyntax$class_object;

#endif	/* _JC_gnu_regexp_RESyntax_H_ */
